==> dotnet9_9.0.110-9.0.9.orig.tar.xz: src/efcore/.github/SUPPORT.md <==
Getting Support
===============

Security Issues
---------------

If you believe you have an issue that affects the security of the platform, please email your issue to secure@microsoft.com. You may even be eligible for our [bug bounty](https://technet.microsoft.com/en-us/mt764065.aspx) by doing this.

Bugs & Feature Requests
-----------------------

If you encounter a bug while using the product or would like to request a new feature, please [submit an issue](https://github.com/dotnet/efcore/issues/new) on our GitHub repository.

Documentation
-------------

We strive to maintain comprehensive [documentation for Entity Framework Core](https://docs.microsoft.com/ef/core/). If the topic you're looking for isn't covered, please let us know on the [aspnet/EntityFramework.Docs](https://github.com/aspnet/EntityFramework.Docs/issues/new) repository.

Community Support
-----------------

If you have a specific question about using the product, we encourage you to [ask it on Stack Overflow](https://stackoverflow.com/questions/tagged/entity-framework-core*).

Official Support
----------------

Entity Framework Core is covered by Microsoft's [.NET Core Support Policy](https://dotnet.microsoft.com/platform/support/policy/dotnet-core). If you've tried all the optoins above and are still looking for help, you may wish to [contact a Microsoft Support professional](http://support.microsoft.com/supportforbusiness/productselection?sapId=bec2bc54-b200-6962-301f-f098532f27b2). Please note that personal help may incur a fee.

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/efcore/.github/SUPPORT.md <==
Getting Support
===============

Security Issues
---------------

If you believe you have an issue that affects the security of the platform, please email your issue to secure@microsoft.com. You may even be eligible for our [bug bounty](https://technet.microsoft.com/en-us/mt764065.aspx) by doing this.

Bugs & Feature Requests
-----------------------

If you encounter a bug while using the product or would like to request a new feature, please [submit an issue](https://github.com/dotnet/efcore/issues/new) on our GitHub repository.

Documentation
-------------

We strive to maintain comprehensive [documentation for Entity Framework Core](https://docs.microsoft.com/ef/core/). If the topic you're looking for isn't covered, please let us know on the [aspnet/EntityFramework.Docs](https://github.com/aspnet/EntityFramework.Docs/issues/new) repository.

Community Support
-----------------

If you have a specific question about using the product, we encourage you to [ask it on Stack Overflow](https://stackoverflow.com/questions/tagged/entity-framework-core*).

Official Support
----------------

Entity Framework Core is covered by Microsoft's [.NET Core Support Policy](https://dotnet.microsoft.com/platform/support/policy/dotnet-core). If you've tried all the options above and are still looking for help, you may wish to [contact a Microsoft Support professional](http://support.microsoft.com/supportforbusiness/productselection?sapId=bec2bc54-b200-6962-301f-f098532f27b2). Please note that personal help may incur a fee.
